R/create_all_tif.R
create_all_tif.RdThe function creates tif files with maps for all crop and system combinations for which area information
was allocated by the model. Maps are both created for harvested (ha) and physical (pa) area. Files are
saved in the /processed_data/results/{model}/maps folder.
create_all_tif(param)