create_folders creates the folder structure that is needed store raw
data, processed data and parameters for mapspamc.
create_folders(param = NULL)create_folders creates two folders in the model_path, set by the user:
mappings and processed_data (including subfolders). It copies a number of cvs files
into the mappings folder, which contain several data tables that are needed to run
the model and, if needed can be adjusted by the user. If set by the user a mapspamc_db
folder is created in db_path. Otherwise the folder is created in the main model folder.
if (FALSE) { # \dontrun{
create_folders(param)
} # }