Combines all elements of the synergy cropland extent (median and maximum cropland per grid cell and rank), with information on the location of the subnational units and fixes potential inconsistencies (e.g. cropland area larger than grid cell size).
prepare_cropland(param)if (FALSE) { # \dontrun{
prepare_cropland(param)
} # }