Combines all elements of the synergy irrigated area extent (maximum irrigated area and rank), with information on the location of the subnational units and fixes potential inconsistencies (e.g. irrigated area larger than grid cell size).
prepare_irrigated_area(param)if (FALSE) { # \dontrun{
prepare_irrigated_area(param)
} # }